// Generated by gir (https://github.com/gtk-rs/gir @ b3d444a058cf)
// from 
// from gir-files (https://github.com/gtk-rs/gir-files.git @ 5c1e490fe50a)
// DO NOT EDIT

#include "manual.h"
#include <stdalign.h>
#include <stdio.h>

int main() {
    printf("%s;%zu;%zu\n", "ShumateCompassClass", sizeof(ShumateCompassClass), alignof(ShumateCompassClass));
    printf("%s;%zu;%zu\n", "ShumateCoordinate", sizeof(ShumateCoordinate), alignof(ShumateCoordinate));
    printf("%s;%zu;%zu\n", "ShumateCoordinateClass", sizeof(ShumateCoordinateClass), alignof(ShumateCoordinateClass));
    printf("%s;%zu;%zu\n", "ShumateDataSource", sizeof(ShumateDataSource), alignof(ShumateDataSource));
    printf("%s;%zu;%zu\n", "ShumateDataSourceClass", sizeof(ShumateDataSourceClass), alignof(ShumateDataSourceClass));
    printf("%s;%zu;%zu\n", "ShumateDataSourceRequest", sizeof(ShumateDataSourceRequest), alignof(ShumateDataSourceRequest));
    printf("%s;%zu;%zu\n", "ShumateDataSourceRequestClass", sizeof(ShumateDataSourceRequestClass), alignof(ShumateDataSourceRequestClass));
    printf("%s;%zu;%zu\n", "ShumateFileCacheClass", sizeof(ShumateFileCacheClass), alignof(ShumateFileCacheClass));
    printf("%s;%zu;%zu\n", "ShumateFileCacheError", sizeof(ShumateFileCacheError), alignof(ShumateFileCacheError));
    printf("%s;%zu;%zu\n", "ShumateGeometryType", sizeof(ShumateGeometryType), alignof(ShumateGeometryType));
    printf("%s;%zu;%zu\n", "ShumateLayer", sizeof(ShumateLayer), alignof(ShumateLayer));
    printf("%s;%zu;%zu\n", "ShumateLayerClass", sizeof(ShumateLayerClass), alignof(ShumateLayerClass));
    printf("%s;%zu;%zu\n", "ShumateLicenseClass", sizeof(ShumateLicenseClass), alignof(ShumateLicenseClass));
    printf("%s;%zu;%zu\n", "ShumateLocationInterface", sizeof(ShumateLocationInterface), alignof(ShumateLocationInterface));
    printf("%s;%zu;%zu\n", "ShumateMapClass", sizeof(ShumateMapClass), alignof(ShumateMapClass));
    printf("%s;%zu;%zu\n", "ShumateMapLayerClass", sizeof(ShumateMapLayerClass), alignof(ShumateMapLayerClass));
    printf("%s;%zu;%zu\n", "ShumateMapProjection", sizeof(ShumateMapProjection), alignof(ShumateMapProjection));
    printf("%s;%zu;%zu\n", "ShumateMapSource", sizeof(ShumateMapSource), alignof(ShumateMapSource));
    printf("%s;%zu;%zu\n", "ShumateMapSourceClass", sizeof(ShumateMapSourceClass), alignof(ShumateMapSourceClass));
    printf("%s;%zu;%zu\n", "ShumateMapSourceRegistryClass", sizeof(ShumateMapSourceRegistryClass), alignof(ShumateMapSourceRegistryClass));
    printf("%s;%zu;%zu\n", "ShumateMarker", sizeof(ShumateMarker), alignof(ShumateMarker));
    printf("%s;%zu;%zu\n", "ShumateMarkerClass", sizeof(ShumateMarkerClass), alignof(ShumateMarkerClass));
    printf("%s;%zu;%zu\n", "ShumateMarkerLayerClass", sizeof(ShumateMarkerLayerClass), alignof(ShumateMarkerLayerClass));
    printf("%s;%zu;%zu\n", "ShumatePathLayerClass", sizeof(ShumatePathLayerClass), alignof(ShumatePathLayerClass));
    printf("%s;%zu;%zu\n", "ShumatePointClass", sizeof(ShumatePointClass), alignof(ShumatePointClass));
    printf("%s;%zu;%zu\n", "ShumateRasterRendererClass", sizeof(ShumateRasterRendererClass), alignof(ShumateRasterRendererClass));
    printf("%s;%zu;%zu\n", "ShumateScaleClass", sizeof(ShumateScaleClass), alignof(ShumateScaleClass));
    printf("%s;%zu;%zu\n", "ShumateSimpleMapClass", sizeof(ShumateSimpleMapClass), alignof(ShumateSimpleMapClass));
    printf("%s;%zu;%zu\n", "ShumateState", sizeof(ShumateState), alignof(ShumateState));
    printf("%s;%zu;%zu\n", "ShumateStyleError", sizeof(ShumateStyleError), alignof(ShumateStyleError));
    printf("%s;%zu;%zu\n", "ShumateSymbolEventClass", sizeof(ShumateSymbolEventClass), alignof(ShumateSymbolEventClass));
    printf("%s;%zu;%zu\n", "ShumateTileClass", sizeof(ShumateTileClass), alignof(ShumateTileClass));
    printf("%s;%zu;%zu\n", "ShumateTileDownloaderClass", sizeof(ShumateTileDownloaderClass), alignof(ShumateTileDownloaderClass));
    printf("%s;%zu;%zu\n", "ShumateTileDownloaderError", sizeof(ShumateTileDownloaderError), alignof(ShumateTileDownloaderError));
    printf("%s;%zu;%zu\n", "ShumateUnit", sizeof(ShumateUnit), alignof(ShumateUnit));
    printf("%s;%zu;%zu\n", "ShumateVectorReaderClass", sizeof(ShumateVectorReaderClass), alignof(ShumateVectorReaderClass));
    printf("%s;%zu;%zu\n", "ShumateVectorReaderIterClass", sizeof(ShumateVectorReaderIterClass), alignof(ShumateVectorReaderIterClass));
    printf("%s;%zu;%zu\n", "ShumateVectorRendererClass", sizeof(ShumateVectorRendererClass), alignof(ShumateVectorRendererClass));
    printf("%s;%zu;%zu\n", "ShumateVectorSpriteClass", sizeof(ShumateVectorSpriteClass), alignof(ShumateVectorSpriteClass));
    printf("%s;%zu;%zu\n", "ShumateVectorSpriteSheetClass", sizeof(ShumateVectorSpriteSheetClass), alignof(ShumateVectorSpriteSheetClass));
    printf("%s;%zu;%zu\n", "ShumateViewportClass", sizeof(ShumateViewportClass), alignof(ShumateViewportClass));
    return 0;
}
