// Generated by gir (https://github.com/gtk-rs/gir @ b3d444a058cf)
// from 
// from gir-files (https://github.com/gtk-rs/gir-files.git @ 5c1e490fe50a)
// DO NOT EDIT

#include "manual.h"
#include <stdio.h>

#define PRINT_CONSTANT(CONSTANT_NAME) \
    printf("%s;", #CONSTANT_NAME); \
    printf(_Generic((CONSTANT_NAME), \
                    char *: "%s", \
                    const char *: "%s", \
                    char: "%c", \
                    signed char: "%hhd", \
                    unsigned char: "%hhu", \
                    short int: "%hd", \
                    unsigned short int: "%hu", \
                    int: "%d", \
                    unsigned int: "%u", \
                    long: "%ld", \
                    unsigned long: "%lu", \
                    long long: "%lld", \
                    unsigned long long: "%llu", \
                    float: "%f", \
                    double: "%f", \
                    long double: "%ld"), \
           CONSTANT_NAME); \
    printf("\n");

int main() {
    PRINT_CONSTANT((gint) SHUMATE_FILE_CACHE_ERROR_FAILED);
    PRINT_CONSTANT((gint) SHUMATE_GEOMETRY_TYPE_LINESTRING);
    PRINT_CONSTANT((gint) SHUMATE_GEOMETRY_TYPE_MULTILINESTRING);
    PRINT_CONSTANT((gint) SHUMATE_GEOMETRY_TYPE_MULTIPOINT);
    PRINT_CONSTANT((gint) SHUMATE_GEOMETRY_TYPE_MULTIPOLYGON);
    PRINT_CONSTANT((gint) SHUMATE_GEOMETRY_TYPE_POINT);
    PRINT_CONSTANT((gint) SHUMATE_GEOMETRY_TYPE_POLYGON);
    PRINT_CONSTANT((gint) SHUMATE_GEOMETRY_TYPE_UNKNOWN);
    PRINT_CONSTANT(SHUMATE_MAJOR_VERSION);
    PRINT_CONSTANT((gint) SHUMATE_MAP_PROJECTION_MERCATOR);
    PRINT_CONSTANT(SHUMATE_MAP_SOURCE_MFF_RELIEF);
    PRINT_CONSTANT(SHUMATE_MAP_SOURCE_OSM_CYCLE_MAP);
    PRINT_CONSTANT(SHUMATE_MAP_SOURCE_OSM_MAPNIK);
    PRINT_CONSTANT(SHUMATE_MAP_SOURCE_OSM_TRANSPORT_MAP);
    PRINT_CONSTANT(SHUMATE_MAP_SOURCE_OWM_CLOUDS);
    PRINT_CONSTANT(SHUMATE_MAP_SOURCE_OWM_PRECIPITATION);
    PRINT_CONSTANT(SHUMATE_MAP_SOURCE_OWM_PRESSURE);
    PRINT_CONSTANT(SHUMATE_MAP_SOURCE_OWM_TEMPERATURE);
    PRINT_CONSTANT(SHUMATE_MAP_SOURCE_OWM_WIND);
    PRINT_CONSTANT(SHUMATE_MAX_LATITUDE);
    PRINT_CONSTANT(SHUMATE_MAX_LONGITUDE);
    PRINT_CONSTANT(SHUMATE_MIN_LATITUDE);
    PRINT_CONSTANT(SHUMATE_MIN_LONGITUDE);
    PRINT_CONSTANT((gint) SHUMATE_STATE_DONE);
    PRINT_CONSTANT((gint) SHUMATE_STATE_LOADED);
    PRINT_CONSTANT((gint) SHUMATE_STATE_LOADING);
    PRINT_CONSTANT((gint) SHUMATE_STATE_NONE);
    PRINT_CONSTANT((gint) SHUMATE_STYLE_ERROR_FAILED);
    PRINT_CONSTANT((gint) SHUMATE_STYLE_ERROR_INVALID_EXPRESSION);
    PRINT_CONSTANT((gint) SHUMATE_STYLE_ERROR_MALFORMED_STYLE);
    PRINT_CONSTANT((gint) SHUMATE_STYLE_ERROR_SUPPORT_OMITTED);
    PRINT_CONSTANT((gint) SHUMATE_STYLE_ERROR_UNSUPPORTED);
    PRINT_CONSTANT((gint) SHUMATE_STYLE_ERROR_UNSUPPORTED_LAYER);
    PRINT_CONSTANT((gint) SHUMATE_TILE_DOWNLOADER_ERROR_BAD_RESPONSE);
    PRINT_CONSTANT((gint) SHUMATE_TILE_DOWNLOADER_ERROR_COULD_NOT_CONNECT);
    PRINT_CONSTANT((gint) SHUMATE_TILE_DOWNLOADER_ERROR_FAILED);
    PRINT_CONSTANT((gint) SHUMATE_TILE_DOWNLOADER_ERROR_MALFORMED_URL);
    PRINT_CONSTANT((gint) SHUMATE_TILE_DOWNLOADER_ERROR_OFFLINE);
    PRINT_CONSTANT((gint) SHUMATE_UNIT_BOTH);
    PRINT_CONSTANT((gint) SHUMATE_UNIT_IMPERIAL);
    PRINT_CONSTANT((gint) SHUMATE_UNIT_METRIC);
    return 0;
}
